==> taboola_sdk-0.3.3.tar.gz: example/lib/main.dart <==
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:taboola_sdk_example/screens/listView_example.dart';
import 'package:taboola_sdk_example/screens/publishers/ali_test.dart';
import 'package:taboola_sdk_example/screens/publishers/nikib_test.dart';

// import screens
import 'package:taboola_sdk_example/screens/single_child_scroll_view_test.dart';
import 'package:taboola_sdk_example/screens/taboola_custom_scrollview_screen.dart';
import 'package:taboola_sdk_example/screens/taboola_dedup_screen.dart';
import 'package:taboola_sdk_example/screens/taboola_tabs_screen.dart';
import 'package:taboola_sdk_example/screens/taboola_pageview_screen.dart';
import 'package:taboola_sdk_example/DefaultProperties.dart'
    as PublisherProperties;
import 'package:taboola_sdk/taboola.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(home: new HomeScreen());
  }
}

class HomeScreen extends StatefulWidget {
  @override
  State<HomeScreen> createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  late Widget displayedScreen;
  bool keepAlive = false;

  @override
  void initState() {
    super.initState();

    // We want the test app to show logs, current SDK default is to not show logs.
//    Taboola.setLogsEnabled(false);
    Taboola.setLogsEnabled(true);

    // Set default screen
//    displayedScreen = TaboolaTabsScreen(PublisherProperties.publisher, PublisherProperties.pageUrl, PublisherProperties.pageType, PublisherProperties.placement, PublisherProperties.mode);
    displayedScreen = TaboolaDedupScreen(keepAlive);
    //   displayedScreen = NikiB();
//    displayedScreen = AliTest();
//    displayedScreen = SingleChildScrollViewTest();
//    displayedScreen = TOnlineScreen("exampleArticle");
//    displayedScreen = TaboolaPageViewScreen(PublisherProperties.publisher, PublisherProperties.pageUrl, PublisherProperties.pageType, PublisherProperties.placement, PublisherProperties.mode);

    // Allow gesture debugging
//    debugPrintGestureArenaDiagnostics = true;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        systemOverlayStyle: SystemUiOverlayStyle.dark,
        title: Text('TaboolaFlutterDemo'),
      ),
      body: Center(
        child: displayedScreen,
      ),
      drawer: Drawer(
        // Add a ListView to the drawer. This ensures the user can scroll
        // through the options in the drawer if there isn't enough vertical
        // space to fit everything.
        child: ListView(
          // Important: Remove any padding from the ListView.
          padding: EdgeInsets.zero,
          children: <Widget>[
            DrawerHeader(
              child: Text('Taboola Sample Screens'),
              decoration: BoxDecoration(
                color: Colors.blue,
              ),
            ),
            ListTile(
              title: Text("Is keep alive Unit?"),
              trailing: Switch(
                // This bool value toggles the switch.
                value: keepAlive,
                activeColor: Colors.blueAccent,
                onChanged: (bool value) {
                  // This is called when the user toggles the switch.
                  setState(() {
                    keepAlive = value;
                  });
                },
              ),
            ),
            ListTile(
              title: Text('SingleChildScrollView'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen = SingleChildScrollViewTest(keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
            ListTile(
              title: Text('Dedup'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen = TaboolaDedupScreen(keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
            ListTile(
              title: Text('ListViewExample'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen =
                      CustomListViewPageFeedAndWidget(isKeepAlive: keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
            ListTile(
              title: Text('TaboolaClassic | CustomScrollView w/ Feed'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen = TaboolaCustomScrollviewScreen(
                      PublisherProperties.publisher,
                      PublisherProperties.pageUrl,
                      PublisherProperties.pageType,
                      PublisherProperties.placement,
                      PublisherProperties.mode,
                      keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
            ListTile(
              title: Text('TaboolaClassic | Tabs w/ Feed'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen = TaboolaTabsScreen(
                      PublisherProperties.publisher,
                      PublisherProperties.pageUrl,
                      PublisherProperties.pageType,
                      PublisherProperties.placement,
                      PublisherProperties.mode,
                      keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
            ListTile(
              title: Text('TaboolaClassic | PageView w/ Feed'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen = TaboolaPageViewScreen(
                      PublisherProperties.publisher,
                      PublisherProperties.pageUrl,
                      PublisherProperties.pageType,
                      PublisherProperties.placement,
                      PublisherProperties.mode,
                      keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
            ListTile(
              title: Text('TaboolaClassic | Ali\'s Case'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen = AliTest(keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
            ListTile(
              title: Text('TaboolaClassic | Niki Bs Case'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen = NikiB(keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
          ],
        ),
      ),
    );
  }
}

==> taboola_sdk-0.3.4.tar.gz: example/lib/main.dart <==
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:taboola_sdk_example/screens/listView_example.dart';
import 'package:taboola_sdk_example/screens/publishers/ali_test.dart';
import 'package:taboola_sdk_example/screens/publishers/nikib_test.dart';

// import screens
import 'package:taboola_sdk_example/screens/single_child_scroll_view_test.dart';
import 'package:taboola_sdk_example/screens/taboola_custom_scrollview_screen.dart';
import 'package:taboola_sdk_example/screens/taboola_dedup_screen.dart';
import 'package:taboola_sdk_example/screens/taboola_tabs_screen.dart';
import 'package:taboola_sdk_example/screens/taboola_pageview_screen.dart';
import 'package:taboola_sdk_example/DefaultProperties.dart'
    as PublisherProperties;
import 'package:taboola_sdk/taboola.dart';

void main() => runApp(MyApp());

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(home: new HomeScreen());
  }
}

class HomeScreen extends StatefulWidget {
  @override
  State<HomeScreen> createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  late Widget displayedScreen;
  bool keepAlive = false;

  @override
  void initState() {
    super.initState();

    // We want the test app to show logs, current SDK default is to not show logs.
//    Taboola.setLogsEnabled(false);
    Taboola.setLogsEnabled(true);

    // Set default screen
//    displayedScreen = TaboolaTabsScreen(PublisherProperties.publisher, PublisherProperties.pageUrl, PublisherProperties.pageType, PublisherProperties.placement, PublisherProperties.mode);
    displayedScreen = TaboolaCustomScrollviewScreen(
        PublisherProperties.publisher,
        PublisherProperties.pageUrl,
        PublisherProperties.pageType,
        PublisherProperties.placement,
        PublisherProperties.mode,
        keepAlive);
    //   displayedScreen = NikiB();
//    displayedScreen = AliTest();
//    displayedScreen = SingleChildScrollViewTest();
//    displayedScreen = TOnlineScreen("exampleArticle");
//    displayedScreen = TaboolaPageViewScreen(PublisherProperties.publisher, PublisherProperties.pageUrl, PublisherProperties.pageType, PublisherProperties.placement, PublisherProperties.mode);

    // Allow gesture debugging
//    debugPrintGestureArenaDiagnostics = true;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        systemOverlayStyle: SystemUiOverlayStyle.dark,
        title: Text('TaboolaFlutterDemo'),
      ),
      body: Center(
        child: displayedScreen,
      ),
      drawer: Drawer(
        // Add a ListView to the drawer. This ensures the user can scroll
        // through the options in the drawer if there isn't enough vertical
        // space to fit everything.
        child: ListView(
          // Important: Remove any padding from the ListView.
          padding: EdgeInsets.zero,
          children: <Widget>[
            DrawerHeader(
              child: Text('Taboola Sample Screens'),
              decoration: BoxDecoration(
                color: Colors.blue,
              ),
            ),
            ListTile(
              title: Text("Is keep alive Unit?"),
              trailing: Switch(
                // This bool value toggles the switch.
                value: keepAlive,
                activeColor: Colors.blueAccent,
                onChanged: (bool value) {
                  // This is called when the user toggles the switch.
                  setState(() {
                    keepAlive = value;
                  });
                },
              ),
            ),
            ListTile(
              title: Text('SingleChildScrollView'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen = SingleChildScrollViewTest(keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
            ListTile(
              title: Text('Dedup and ExtraProperties'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen = TaboolaDedupAndExtraPropertiesScreen(keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
            ListTile(
              title: Text('ListViewExample'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen =
                      CustomListViewPageFeedAndWidget(isKeepAlive: keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
            ListTile(
              title: Text('TaboolaClassic | CustomScrollView w/ Feed'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen = TaboolaCustomScrollviewScreen(
                      PublisherProperties.publisher,
                      PublisherProperties.pageUrl,
                      PublisherProperties.pageType,
                      PublisherProperties.placement,
                      PublisherProperties.mode,
                      keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
            ListTile(
              title: Text('TaboolaClassic | Tabs w/ Feed'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen = TaboolaTabsScreen(
                      PublisherProperties.publisher,
                      PublisherProperties.pageUrl,
                      PublisherProperties.pageType,
                      PublisherProperties.placement,
                      PublisherProperties.mode,
                      keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
            ListTile(
              title: Text('TaboolaClassic | PageView w/ Feed'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen = TaboolaPageViewScreen(
                      PublisherProperties.publisher,
                      PublisherProperties.pageUrl,
                      PublisherProperties.pageType,
                      PublisherProperties.placement,
                      PublisherProperties.mode,
                      keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
            ListTile(
              title: Text('TaboolaClassic | Ali\'s Case'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen = AliTest(keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
            ListTile(
              title: Text('TaboolaClassic | Niki Bs Case'),
              trailing: Icon(Icons.arrow_forward),
              onTap: () {
                // Update the state of the app.
                setState(() {
                  displayedScreen = NikiB(keepAlive);
                });
                // Close the drawer
                Navigator.pop(context);
              },
            ),
          ],
        ),
      ),
    );
  }
}
